@@ -1,6 +1,10 @@
 package v1alpha1
 
 import (
+	"crypto/sha256"
+	"encoding/hex"
+	"encoding/json"
+	"fmt"
 	"strconv"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -78,17 +82,35 @@ type ValueReference struct {
 	PackageRef   *PackageValueSource   `json:"packageRef,omitempty"`
 }
 
+type InlineValueConfiguration struct {
+	Value *string `json:"value,omitempty"`
+}
+
 // +kubebuilder:validation:MinProperties:=1
 // +kubebuilder:validation:MaxProperties:=1
 type ValueConfiguration struct {
-	Value     *string         `json:"value,omitempty"`
-	ValueFrom *ValueReference `json:"valueFrom,omitempty"`
+	InlineValueConfiguration `json:",inline"`
+	ValueFrom                *ValueReference `json:"valueFrom,omitempty"`
 }
 
 // PackageSpec defines the desired state
 type PackageSpec struct {
 	PackageInfo PackageInfoTemplate           `json:"packageInfo"`
 	Values      map[string]ValueConfiguration `json:"values,omitempty"`
+
+	// Suspend indicates that reconciliation of this resource should be suspended.
+	//
+	// +kubebuilder:validation:Optional
+	Suspend bool `json:"suspend"`
+}
+
+func (spec *PackageSpec) Hashed() (string, error) {
+	h := sha256.New()
+	if err := json.NewEncoder(h).Encode(spec); err != nil {
+		return "", fmt.Errorf("failed to encode package spec: %w", err)
+	} else {
+		return hex.EncodeToString(h.Sum(nil)), nil
+	}
 }
 
 // PackageStatus defines the observed state
