@@ -20,14 +20,11 @@ import (
 	"strings"
 
 	"github.com/invopop/jsonschema"
+	corev1 "k8s.io/api/core/v1"
 	apiextv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-type HelmManifest struct {
-	// RepositoryUrl is the remote URL of the helm repository. This is the same URL you would use
-	// if you use "helm repo add ...".
-	RepositoryUrl string `json:"repositoryUrl" jsonschema:"required"`
+type HelmRelease struct {
 	// ChartName is the name of the chart that represents this package.
 	ChartName string `json:"chartName" jsonschema:"required"`
 	// ChartVersion of the chart that should be installed.
@@ -36,6 +33,21 @@ type HelmManifest struct {
 	Values *JSON `json:"values,omitempty"`
 }
 
+// +kubebuilder:validation:XValidation:message="",rule="size(self.releases) > 0 || (has(self.chartName) && has(self.chartVersion))"
+type HelmManifest struct {
+	// RepositoryUrl is the remote URL of the helm repository. This is the same URL you would use
+	// if you use "helm repo add ...".
+	RepositoryUrl string        `json:"repositoryUrl" jsonschema:"required"`
+	Releases      []HelmRelease `json:"releases,omitempty" jsonschema:"oneof_required=MultiChart"`
+
+	// ChartName is the name of the chart that represents this package.
+	ChartName string `json:"chartName,omitempty" jsonschema:"oneof_required=SingleChart"`
+	// ChartVersion of the chart that should be installed.
+	ChartVersion string `json:"chartVersion,omitempty" jsonschema:"oneof_required=SingleChart"`
+	// Values that should be used for the helm release
+	Values *JSON `json:"values,omitempty"`
+}
+
 func (obj HelmManifest) IsOCIRepository() bool {
 	return strings.HasPrefix(obj.RepositoryUrl, "oci://")
 }
@@ -83,6 +95,18 @@ type Component struct {
 	Name          string `json:"name" jsonschema:"required"`
 	InstalledName string `json:"installedName,omitempty"`
 	Version       string `json:"version,omitempty"`
+	// Specify configuration for this component
+	Values ComponentValues `json:"values,omitempty"`
+}
+
+type ComponentValues map[string]InlineValueConfiguration
+
+func (values ComponentValues) AsPackageValues() map[string]ValueConfiguration {
+	result := make(map[string]ValueConfiguration, len(values))
+	for name, value := range values {
+		result[name] = ValueConfiguration{InlineValueConfiguration: value}
+	}
+	return result
 }
 
 // +kubebuilder:validation:Enum=Cluster;Namespaced
@@ -110,9 +134,14 @@ func (s *PackageScope) IsNamespaced() bool {
 	return s != nil && *s == ScopeNamespaced
 }
 
-type TransitiveResource struct {
-	metav1.GroupVersionKind `json:",inline"`
-	Name                    string `json:"name" jsonschema:"required"`
+type TransformationSource struct {
+	Resource *corev1.TypedLocalObjectReference `json:"resource,omitempty"`
+	Path     string                            `json:"path" jsonschema:"required"`
+}
+
+type TransformationDefinition struct {
+	Source  TransformationSource    `json:"source" jsonschema:"required"`
+	Targets []ValueDefinitionTarget `json:"targets" jsonschema:"required"`
 }
 
 type PackageManifest struct {
@@ -126,10 +155,11 @@ type PackageManifest struct {
 	// Helm instructs the controller to create a helm release when installing this package.
 	Helm *HelmManifest `json:"helm,omitempty"`
 	// Kustomize instructs the controller to apply a kustomization when installing this package [PLACEHOLDER].
-	Kustomize           *KustomizeManifest         `json:"kustomize,omitempty"`
-	Manifests           []PlainManifest            `json:"manifests,omitempty"`
-	ValueDefinitions    map[string]ValueDefinition `json:"valueDefinitions,omitempty"`
-	TransitiveResources []TransitiveResource       `json:"transitiveResources,omitempty"`
+	Kustomize           *KustomizeManifest                 `json:"kustomize,omitempty"`
+	Manifests           []PlainManifest                    `json:"manifests,omitempty"`
+	ValueDefinitions    map[string]ValueDefinition         `json:"valueDefinitions,omitempty"`
+	Transformations     []TransformationDefinition         `json:"transformations,omitempty"`
+	TransitiveResources []corev1.TypedLocalObjectReference `json:"transitiveResources,omitempty"`
 	// DefaultNamespace to install the package. May be overridden.
 	DefaultNamespace string              `json:"defaultNamespace,omitempty" jsonschema:"required"`
 	Entrypoints      []PackageEntrypoint `json:"entrypoints,omitempty"`
