@@ -9,6 +9,8 @@ import (
 	"os"
 	"strings"
 
+	repoerror "github.com/glasskube/glasskube/internal/repo/error"
+
 	"github.com/fatih/color"
 	"github.com/glasskube/glasskube/api/v1alpha1"
 	"github.com/glasskube/glasskube/internal/clientutils"
@@ -23,6 +25,7 @@ import (
 	"github.com/glasskube/glasskube/pkg/describe"
 	"github.com/spf13/cobra"
 	"github.com/yuin/goldmark"
+	"github.com/yuin/goldmark/extension"
 	"github.com/yuin/goldmark/renderer"
 	goldmarkutil "github.com/yuin/goldmark/util"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -63,7 +66,9 @@ var describeCmd = &cobra.Command{
 				// package not installed -> use latest manifest from repo
 				if lvErr != nil {
 					fmt.Fprintf(os.Stderr, "❌ Could not get latest info for %v: %v\n", pkgName, lvErr)
-					cliutils.ExitWithError()
+					if repoerror.IsComplete(lvErr) {
+						cliutils.ExitWithError()
+					}
 				}
 
 				manifest = latestManifest
@@ -122,7 +127,6 @@ var describeCmd = &cobra.Command{
 		}
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "❌ Could not get repos for %v: %v\n", pkgName, err)
-			cliutils.ExitWithError()
 		}
 
 		bold := color.New(color.Bold).SprintFunc()
@@ -141,6 +145,7 @@ var describeCmd = &cobra.Command{
 				fmt.Println(bold("Status:     "), status(pkgStatus))
 				fmt.Println(bold("Message:    "), message(pkgStatus))
 				fmt.Println(bold("Auto-Update:"), clientutils.AutoUpdateString(pkg, "Disabled"))
+				fmt.Println(bold("Suspended:  "), boolYesNo(pkg.GetSpec().Suspend))
 			} else if len(pkgs) > 0 {
 				fmt.Println()
 				fmt.Println(bold("Instances:"))
@@ -153,6 +158,7 @@ var describeCmd = &cobra.Command{
 					fmt.Println(bold("    Status:     "), status(pkgStatus))
 					fmt.Println(bold("    Message:    "), message(pkgStatus))
 					fmt.Println(bold("    Auto-Update:"), clientutils.AutoUpdateString(&pkg, "Disabled"))
+					fmt.Println(bold("    Suspended:  "), boolYesNo(pkg.Spec.Suspend))
 				}
 			}
 
@@ -168,6 +174,12 @@ var describeCmd = &cobra.Command{
 				printDependencies(manifest)
 			}
 
+			if len(manifest.Components) > 0 {
+				fmt.Println()
+				fmt.Println(bold("Components:"))
+				printComponents(manifest)
+			}
+
 			fmt.Println()
 			fmt.Println(bold("Package repositories:"))
 			printRepositories(pkg, repos)
@@ -229,6 +241,16 @@ func printDependencies(manifest *v1alpha1.PackageManifest) {
 	}
 }
 
+func printComponents(manifest *v1alpha1.PackageManifest) {
+	for _, cmp := range manifest.Components {
+		fmt.Printf(" * %v", cmp.Name)
+		if len(cmp.Version) > 0 {
+			fmt.Printf(" (%v)", cmp.Version)
+		}
+		fmt.Println()
+	}
+}
+
 func printRepositories(pkg ctrlpkg.Package, repos []v1alpha1.PackageRepository) {
 	for _, repo := range repos {
 		fmt.Fprintf(os.Stderr, " * %v", repo.Name)
@@ -306,6 +328,9 @@ func printValueConfigurations(w io.Writer, values map[string]v1alpha1.ValueConfi
 
 func printMarkdown(w io.Writer, text string) {
 	md := goldmark.New(
+		goldmark.WithExtensions(
+			extension.Linkify,
+		),
 		goldmark.WithRenderer(renderer.NewRenderer(
 			renderer.WithNodeRenderers(
 				goldmarkutil.Prioritized(cliutils.MarkdownRenderer(), 1000),
@@ -320,6 +345,13 @@ func printMarkdown(w io.Writer, text string) {
 	}
 }
 
+func boolYesNo(value bool) string {
+	if value {
+		return "Yes"
+	}
+	return "No"
+}
+
 func status(pkgStatus *client.PackageStatus) string {
 	if pkgStatus != nil {
 		switch pkgStatus.Status {
@@ -389,6 +421,7 @@ func createOutputStructure(
 		"status":           "Not Installed",
 		"entrypoints":      manifest.Entrypoints,
 		"dependencies":     manifest.Dependencies,
+		"components":       manifest.Components,
 		"longDescription":  strings.TrimSpace(manifest.LongDescription),
 		"repositories":     repositoriesAsMap(pkg, repos),
 		"references":       referencesAsMap(ctx, pkg, manifest),
@@ -400,6 +433,7 @@ func createOutputStructure(
 		data["autoUpdate"] = pkg.AutoUpdatesEnabled()
 		data["isUpgradable"] = semver.IsUpgradable(pkg.GetSpec().PackageInfo.Version, latestVersion)
 		data["status"] = client.GetStatusOrPending(pkg).Status
+		data["suspend"] = pkg.GetSpec().Suspend
 	}
 	if len(instances) > 0 {
 		data["instances"] = instances
