@@ -5,7 +5,10 @@ import (
 	"os"
 	"strings"
 
+	v1 "k8s.io/api/core/v1"
+
 	"github.com/glasskube/glasskube/internal/clientutils"
+	"github.com/glasskube/glasskube/internal/namespaces"
 
 	"github.com/fatih/color"
 	"github.com/glasskube/glasskube/api/v1alpha1"
@@ -14,7 +17,6 @@ import (
 	"github.com/glasskube/glasskube/internal/config"
 	"github.com/glasskube/glasskube/internal/dependency"
 	"github.com/glasskube/glasskube/internal/manifestvalues/cli"
-	"github.com/glasskube/glasskube/internal/manifestvalues/flags"
 	"github.com/glasskube/glasskube/internal/maputils"
 	"github.com/glasskube/glasskube/internal/repo"
 	repoclient "github.com/glasskube/glasskube/internal/repo/client"
@@ -29,7 +31,7 @@ import (
 )
 
 var installCmdOptions = struct {
-	flags.ValuesOptions
+	cli.ValuesOptions
 	Version           string
 	Repository        string
 	EnableAutoUpdates bool
@@ -39,7 +41,7 @@ var installCmdOptions = struct {
 	NamespaceOptions
 	DryRunOptions
 }{
-	ValuesOptions: flags.NewOptions(),
+	ValuesOptions: cli.NewOptions(),
 }
 
 var installCmd = &cobra.Command{
@@ -57,6 +59,7 @@ var installCmd = &cobra.Command{
 		valueResolver := cliutils.ValueResolver(ctx)
 		repoClientset := cliutils.RepositoryClientset(ctx)
 		installer := install.NewInstaller(pkgClient)
+		cs := clicontext.KubernetesClientFromContext(ctx)
 
 		opts := metav1.CreateOptions{}
 		if installCmdOptions.DryRun {
@@ -171,14 +174,14 @@ var installCmd = &cobra.Command{
 		}
 
 		if installCmdOptions.IsValuesSet() {
-			if values, err := installCmdOptions.ParseValues(nil); err != nil {
+			if values, err := installCmdOptions.ParseValues(&manifest, nil); err != nil {
 				fmt.Fprintf(os.Stderr, "❌ invalid values in command line flags: %v\n", err)
 				cliutils.ExitWithError()
 			} else {
 				pkgBuilder.WithValues(values)
 			}
 		} else {
-			if values, err := cli.Configure(manifest, nil); err != nil {
+			if values, err := cli.Configure(manifest, cli.WithUseDefaults(installCmdOptions.UseDefault)); err != nil {
 				cancel()
 			} else {
 				pkgBuilder.WithValues(values)
@@ -190,6 +193,15 @@ var installCmd = &cobra.Command{
 				installCmdOptions.EnableAutoUpdates = true
 			}
 		}
+		if installCmdOptions.EnableAutoUpdates {
+			ok, err := clientutils.IsAutoUpdaterInstalled(ctx)
+			if err != nil {
+				fmt.Fprintf(os.Stderr, "! Error: Could not check whether glasskube-autoupdater is installed: %v\n", err)
+			}
+			if !ok {
+				fmt.Fprintf(os.Stderr, "Please install glasskube-autoupdater for automatic updates to be applied.\n")
+			}
+		}
 
 		pkgBuilder.WithAutoUpdates(installCmdOptions.EnableAutoUpdates)
 
@@ -218,6 +230,18 @@ var installCmd = &cobra.Command{
 			fmt.Fprintln(os.Stderr, " * Automatic updates will be", bold("not enabled"))
 		}
 
+		createNamespace := false
+		if installCmdOptions.NamespaceOptions.Namespace != "" {
+			if ok, err := namespaces.Exists(ctx, cs, installCmdOptions.NamespaceOptions.Namespace); !ok {
+				fmt.Fprintf(os.Stderr, " * Namespace %v does not exist and will be created\n",
+					installCmdOptions.NamespaceOptions.Namespace)
+				createNamespace = true
+			} else if err != nil {
+				fmt.Fprintf(os.Stderr, "An error occurred in the Namespace check:\n\n%v\n", err)
+				cliutils.ExitWithError()
+			}
+		}
+
 		if len(pkg.GetSpec().Values) > 0 {
 			fmt.Fprintln(os.Stderr, bold("Configuration:"))
 			printValueConfigurations(os.Stderr, pkg.GetSpec().Values)
@@ -230,6 +254,18 @@ var installCmd = &cobra.Command{
 			cancel()
 		}
 
+		if createNamespace {
+			ns := &v1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: installCmdOptions.NamespaceOptions.Namespace,
+				},
+			}
+			_, err := cs.CoreV1().Namespaces().Create(ctx, ns, metav1.CreateOptions{})
+			if err != nil {
+				fmt.Fprintf(os.Stderr, "An error occurred in creating the Namespace:\n\n%v\n", err)
+				cliutils.ExitWithError()
+			}
+		}
 		if installCmdOptions.NoWait {
 			if err := installer.Install(ctx, pkg, opts); err != nil {
 				fmt.Fprintf(os.Stderr, "An error occurred during installation:\n\n%v\n", err)
