@@ -24,12 +24,15 @@ var uninstallCmdOptions = struct {
 }
 
 var uninstallCmd = &cobra.Command{
-	Use:               "uninstall <package-name>",
-	Short:             "Uninstall a package",
-	Long:              `Uninstall a package.`,
-	Args:              cobra.ExactArgs(1),
-	ValidArgsFunction: completeInstalledPackageNames,
-	PreRun:            cliutils.SetupClientContext(true, &rootCmdOptions.SkipUpdateCheck),
+	Use:   "uninstall <package-name>",
+	Short: "Uninstall a package",
+	Long:  `Uninstall a package.`,
+	Args:  cobra.ExactArgs(1),
+	ValidArgsFunction: installedPackagesCompletionFunc(
+		&uninstallCmdOptions.NamespaceOptions,
+		&uninstallCmdOptions.KindOptions,
+	),
+	PreRun: cliutils.SetupClientContext(true, &rootCmdOptions.SkipUpdateCheck),
 	Run: func(cmd *cobra.Command, args []string) {
 		pkgName := args[0]
 		ctx := cmd.Context()
