@@ -11,16 +11,14 @@ import (
 	"github.com/glasskube/glasskube/internal/clientutils"
 	"github.com/glasskube/glasskube/internal/util"
 
-	"github.com/glasskube/glasskube/internal/controller/ctrlpkg"
-	"github.com/glasskube/glasskube/internal/manifestvalues/cli"
-
 	"github.com/glasskube/glasskube/api/v1alpha1"
 	"github.com/glasskube/glasskube/internal/clicontext"
 	"github.com/glasskube/glasskube/internal/cliutils"
 	"github.com/glasskube/glasskube/internal/config"
+	"github.com/glasskube/glasskube/internal/controller/ctrlpkg"
+	"github.com/glasskube/glasskube/internal/manifestvalues/cli"
 	"github.com/glasskube/glasskube/internal/repo"
 	"github.com/glasskube/glasskube/internal/semver"
-	"github.com/glasskube/glasskube/pkg/client"
 	"github.com/glasskube/glasskube/pkg/kubeconfig"
 	"github.com/glasskube/glasskube/pkg/manifest"
 	"github.com/glasskube/glasskube/pkg/statuswriter"
@@ -29,20 +27,23 @@ import (
 	"k8s.io/client-go/tools/cache"
 )
 
-var updateCmdOptions struct {
+var updateCmdOptions = struct {
+	cli.ValuesOptions
 	Version string
 	Yes     bool
 	DryRunOptions
 	OutputOptions
 	NamespaceOptions
 	KindOptions
+}{
+	ValuesOptions: cli.NewOptions(cli.WithKeepOldValuesFlag),
 }
 
 var updateCmd = &cobra.Command{
 	Use:               "update [<package-name>...]",
 	Short:             "Update some or all packages in your cluster",
 	PreRun:            cliutils.SetupClientContext(true, &rootCmdOptions.SkipUpdateCheck),
-	ValidArgsFunction: completeInstalledPackageNames,
+	ValidArgsFunction: installedPackagesCompletionFunc(&updateCmdOptions.NamespaceOptions, &updateCmdOptions.KindOptions),
 	Run: func(cmd *cobra.Command, args []string) {
 		ctx := cmd.Context()
 
@@ -109,40 +110,51 @@ var updateCmd = &cobra.Command{
 			}
 		}
 
-		if tx != nil && !tx.IsEmpty() {
-			printTransaction(*tx)
-			if !updateCmdOptions.Yes && !cliutils.YesNoPrompt("Do you want to apply these updates?", false) {
-				fmt.Fprintf(os.Stderr, "⛔ Update cancelled. No changes were made.\n")
-				cliutils.ExitSuccess()
-			}
-
-			for _, item := range tx.Items {
-				if item.UpdateRequired() {
-					if err := updateConfigurationIfNeeded(ctx, item.Package, item.Version); err != nil {
-						fmt.Fprintf(os.Stderr, "❌ error updating configuration for %s: %v\n", item.Package.GetName(), err)
-						cliutils.ExitWithError()
+		if tx != nil {
+			if len(tx.ConflictItems) > 0 {
+				for _, conflictItem := range tx.ConflictItems {
+					for _, conflict := range conflictItem.Conflicts {
+						fmt.Fprintf(os.Stderr, "❌ Cannot Update %s due to dependency conflicts: %s\n"+
+							" (required: %s, actual: %s)\n",
+							conflictItem.Package.GetName(), conflict.Actual.Name, conflict.Required.Version, conflict.Actual.Version)
 					}
 				}
-			}
-
-			updatedPackages, err := updater.Apply(
-				ctx,
-				tx,
-				update.ApplyUpdateOptions{
-					Blocking: true,
-					DryRun:   updateCmdOptions.DryRun,
-				})
-			if err != nil {
-				fmt.Fprintf(os.Stderr, "❌ update failed: %v\n", err)
 				cliutils.ExitWithError()
-			}
-			if updateCmdOptions.Output != "" {
-				if out, err := clientutils.Format(updateCmdOptions.Output.OutputFormat(),
-					updateCmdOptions.ShowAll, updatedPackages...); err != nil {
-					fmt.Fprintf(os.Stderr, "❌ failed to marshal output: %v\n", err)
+			} else if !tx.IsEmpty() {
+				printTransaction(*tx)
+				if !updateCmdOptions.Yes && !cliutils.YesNoPrompt("Do you want to apply these updates?", false) {
+					fmt.Fprintf(os.Stderr, "⛔ Update cancelled. No changes were made.\n")
+					cliutils.ExitSuccess()
+				}
+
+				for _, item := range tx.Items {
+					if item.UpdateRequired() {
+						if err := updateConfigurationIfNeeded(ctx, item.Package, item.Version); err != nil {
+							fmt.Fprintf(os.Stderr, "❌ error updating configuration for %s: %v\n", item.Package.GetName(), err)
+							cliutils.ExitWithError()
+						}
+					}
+				}
+
+				updatedPackages, err := updater.Apply(
+					ctx,
+					tx,
+					update.ApplyUpdateOptions{
+						Blocking: true,
+						DryRun:   updateCmdOptions.DryRun,
+					})
+				if err != nil {
+					fmt.Fprintf(os.Stderr, "❌ update failed: %v\n", err)
 					cliutils.ExitWithError()
-				} else {
-					fmt.Print(out)
+				}
+				if updateCmdOptions.Output != "" {
+					if out, err := clientutils.Format(updateCmdOptions.Output.OutputFormat(),
+						updateCmdOptions.ShowAll, updatedPackages...); err != nil {
+						fmt.Fprintf(os.Stderr, "❌ failed to marshal output: %v\n", err)
+						cliutils.ExitWithError()
+					} else {
+						fmt.Print(out)
+					}
 				}
 			}
 		}
@@ -175,33 +187,60 @@ func printTransaction(tx update.UpdateTransaction) {
 	_ = w.Flush()
 }
 
-func completeInstalledPackageNames(
-	cmd *cobra.Command,
-	args []string,
-	toComplete string,
-) (packages []string, dir cobra.ShellCompDirective) {
-	dir = cobra.ShellCompDirectiveNoFileComp
-	config, _, err := kubeconfig.New(config.Kubeconfig)
-	if err != nil {
-		dir &= cobra.ShellCompDirectiveError
-		return
-	}
-	client, err := client.New(config)
-	if err != nil {
-		dir &= cobra.ShellCompDirectiveError
-		return
-	}
-	var packageList v1alpha1.ClusterPackageList
-	if err := client.ClusterPackages().GetAll(cmd.Context(), &packageList); err != nil {
-		dir &= cobra.ShellCompDirectiveError
-		return
-	}
-	for _, pkg := range packageList.Items {
-		if (toComplete == "" || strings.HasPrefix(pkg.GetName(), toComplete)) && !slices.Contains(args, pkg.GetName()) {
-			packages = append(packages, pkg.GetName())
+func installedPackagesCompletionFunc(
+	nsOpts *NamespaceOptions,
+	kindOpts *KindOptions,
+) func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	return func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		dir := cobra.ShellCompDirectiveNoFileComp
+		var packages []string
+
+		config, rawConfig, err := kubeconfig.New(config.Kubeconfig)
+		if err != nil {
+			dir |= cobra.ShellCompDirectiveError
+			return nil, dir
 		}
+
+		ctx, err := clicontext.SetupContext(cmd.Context(), config, rawConfig)
+		if err != nil {
+			dir |= cobra.ShellCompDirectiveError
+			return nil, dir
+		}
+
+		client := cliutils.PackageClient(ctx)
+
+		if (nsOpts == nil || nsOpts.Namespace == "") && (kindOpts == nil || kindOpts.Kind != KindPackage) {
+			var list v1alpha1.ClusterPackageList
+			if err := client.ClusterPackages().GetAll(ctx, &list); err != nil {
+				dir |= cobra.ShellCompDirectiveError
+				return nil, dir
+			}
+			for _, pkg := range list.Items {
+				if (toComplete == "" || strings.HasPrefix(pkg.GetName(), toComplete)) && !slices.Contains(args, pkg.GetName()) {
+					packages = append(packages, pkg.GetName())
+				}
+			}
+		}
+
+		if kindOpts == nil || kindOpts.Kind != KindClusterPackage {
+			ns := ""
+			if nsOpts != nil {
+				ns = nsOpts.GetActualNamespace(ctx)
+			}
+			var list v1alpha1.PackageList
+			if err := client.Packages(ns).GetAll(ctx, &list); err != nil {
+				dir &= cobra.ShellCompDirectiveError
+				return nil, dir
+			}
+			for _, pkg := range list.Items {
+				if (toComplete == "" || strings.HasPrefix(pkg.GetName(), toComplete)) && !slices.Contains(args, pkg.GetName()) {
+					packages = append(packages, pkg.GetName())
+				}
+			}
+		}
+
+		return packages, dir
 	}
-	return
 }
 
 func completeUpgradablePackageVersions(
@@ -217,12 +256,12 @@ func completeUpgradablePackageVersions(
 
 	config, rawConfig, err := kubeconfig.New(config.Kubeconfig)
 	if err != nil {
-		dir &= cobra.ShellCompDirectiveError
+		dir |= cobra.ShellCompDirectiveError
 		return nil, dir
 	}
 	ctx, err := clicontext.SetupContext(cmd.Context(), config, rawConfig)
 	if err != nil {
-		dir &= cobra.ShellCompDirectiveError
+		dir |= cobra.ShellCompDirectiveError
 		return nil, dir
 	}
 	client := cliutils.PackageClient(ctx)
@@ -230,12 +269,13 @@ func completeUpgradablePackageVersions(
 
 	var pkg v1alpha1.ClusterPackage
 	if err := client.ClusterPackages().Get(cmd.Context(), packageName, &pkg); err != nil {
-		dir &= cobra.ShellCompDirectiveError
+		dir |= cobra.ShellCompDirectiveError
 		return nil, dir
 	}
 	var packageIndex repo.PackageIndex
 	if err := repoClient.ForPackage(&pkg).FetchPackageIndex(packageName, &packageIndex); err != nil {
-		return nil, cobra.ShellCompDirectiveError
+		dir |= cobra.ShellCompDirectiveError
+		return nil, dir
 	}
 	versions := make([]string, 0, len(packageIndex.Versions))
 	for _, version := range packageIndex.Versions {
@@ -253,10 +293,18 @@ func updateConfigurationIfNeeded(ctx context.Context, pkg ctrlpkg.Package, newVe
 		return fmt.Errorf("error getting manifest for new version: %v", err)
 	}
 
-	if len(newManifest.ValueDefinitions) > 0 {
+	if updateCmdOptions.ValuesOptions.IsValuesSet() {
+		if values, err := updateCmdOptions.ValuesOptions.ParseValues(newManifest, pkg.GetSpec().Values); err != nil {
+			return err
+		} else {
+			pkg.GetSpec().Values = values
+		}
+	} else if len(newManifest.ValueDefinitions) > 0 || len(pkg.GetSpec().Values) > 0 {
 		if cliutils.YesNoPrompt(fmt.Sprintf("Do you want to update the configuration for %s?", pkg.GetName()), false) {
-
-			values, err := cli.Configure(*newManifest, pkg.GetSpec().Values)
+			values, err := cli.Configure(*newManifest,
+				cli.WithOldValues(pkg.GetSpec().Values),
+				cli.WithUseDefaults(updateCmdOptions.UseDefault),
+			)
 			if err != nil {
 				return fmt.Errorf("error during configuration: %v", err)
 			}
@@ -276,6 +324,7 @@ func init() {
 	updateCmdOptions.OutputOptions.AddFlagsToCommand(updateCmd)
 	updateCmdOptions.KindOptions.AddFlagsToCommand(updateCmd)
 	updateCmdOptions.NamespaceOptions.AddFlagsToCommand(updateCmd)
-	RootCmd.AddCommand(updateCmd)
+	updateCmdOptions.ValuesOptions.AddFlagsToCommand(updateCmd)
 	updateCmdOptions.DryRunOptions.AddFlagsToCommand(updateCmd)
+	RootCmd.AddCommand(updateCmd)
 }
