@@ -3,14 +3,22 @@ package clientutils
 import (
 	"context"
 
+	v1 "k8s.io/api/apps/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	appsv1 "k8s.io/client-go/listers/apps/v1"
+
 	"k8s.io/client-go/rest"
 
 	"github.com/glasskube/glasskube/internal/clicontext"
 	"github.com/google/go-containerregistry/pkg/name"
-	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
 )
 
+const (
+	namespace      = "glasskube-system"
+	deploymentName = "glasskube-controller-manager"
+)
+
 func GetPackageOperatorVersion(ctx context.Context) (string, error) {
 	config := clicontext.ConfigFromContext(ctx)
 	return GetPackageOperatorVersionForConfig(config, ctx)
@@ -22,13 +30,22 @@ func GetPackageOperatorVersionForConfig(config *rest.Config, ctx context.Context
 		return "", err
 	}
 
-	namespace := "glasskube-system"
-	deploymentName := "glasskube-controller-manager"
-	deployment, err := clientset.AppsV1().Deployments(namespace).Get(ctx, deploymentName, v1.GetOptions{})
+	deployment, err := clientset.AppsV1().Deployments(namespace).Get(ctx, deploymentName, metav1.GetOptions{})
 	if err != nil {
 		return "", err
 	}
+	return getVersionOfDeployment(deployment)
+}
 
+func GetPackageOperatorVersionForLister(deploymentLister *appsv1.DeploymentLister) (string, error) {
+	deployment, err := (*deploymentLister).Deployments(namespace).Get(deploymentName)
+	if err != nil {
+		return "", err
+	}
+	return getVersionOfDeployment(deployment)
+}
+
+func getVersionOfDeployment(deployment *v1.Deployment) (string, error) {
 	containers := deployment.Spec.Template.Spec.Containers
 	for _, container := range containers {
 		if container.Name == "manager" {
