@@ -3,6 +3,7 @@ package controller
 import (
 	"context"
 	"fmt"
+	"reflect"
 	"slices"
 	"strings"
 
@@ -20,9 +21,11 @@ import (
 	deputil "github.com/glasskube/glasskube/internal/dependency/util"
 	"github.com/glasskube/glasskube/internal/manifest"
 	"github.com/glasskube/glasskube/internal/manifest/result"
+	"github.com/glasskube/glasskube/internal/manifesttransformations"
 	"github.com/glasskube/glasskube/internal/manifestvalues"
 	"github.com/glasskube/glasskube/internal/names"
 	repoclient "github.com/glasskube/glasskube/internal/repo/client"
+	"github.com/glasskube/glasskube/internal/resourcepatch"
 	"github.com/glasskube/glasskube/internal/telemetry"
 	"github.com/glasskube/glasskube/internal/util"
 	"github.com/glasskube/glasskube/pkg/condition"
@@ -89,7 +92,7 @@ func (r *PackageReconcilerCommon) baseSetup(
 func (r *PackageReconcilerCommon) InitAdapters(builder *builder.Builder) error {
 	for _, adapter := range []manifest.ManifestAdapter{r.HelmAdapter, r.KustomizeAdapter, r.ManifestAdapter} {
 		if adapter != nil {
-			if err := adapter.ControllerInit(builder, r.Client, r.Scheme); err != nil {
+			if err := adapter.ControllerInit(builder, r.Client, r.RepoClientset, r.Scheme); err != nil {
 				return err
 			}
 		}
@@ -101,6 +104,10 @@ func (r *PackageReconcilerCommon) reconcile(ctx context.Context, pkg ctrlpkg.Pac
 	prc := &PackageReconcilationContext{PackageReconcilerCommon: r, pkg: pkg}
 	log := ctrl.LoggerFrom(ctx)
 
+	if pkg.GetSpec().Suspend {
+		return prc.reconcileSuspended(ctx)
+	}
+
 	if !pkg.GetDeletionTimestamp().IsZero() {
 		return prc.reconcileAfterDeletion(ctx)
 	}
@@ -156,7 +163,7 @@ func (r *PackageReconcilationContext) reconcilePackageInfoReady(ctx context.Cont
 		return r.finalize(ctx)
 	}
 
-	var patches []manifestvalues.TargetPatch
+	var patches []resourcepatch.TargetPatch
 	if resolvedValues, err := r.ValueResolver.Resolve(ctx, r.pkg.GetSpec().Values); err != nil {
 		r.setShouldUpdate(
 			conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
@@ -167,7 +174,7 @@ func (r *PackageReconcilationContext) reconcilePackageInfoReady(ctx context.Cont
 			conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
 				condition.ValueConfigurationInvalid, err.Error()))
 		return r.finalizeWithError(ctx, err)
-	} else if p, err := manifestvalues.GeneratePatches(*piManifest, resolvedValues); err != nil {
+	} else if p, err := resourcepatch.GeneratePatches(*piManifest, resolvedValues); err != nil {
 		r.setShouldUpdate(
 			conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
 				condition.InstallationFailed, err.Error()))
@@ -176,6 +183,15 @@ func (r *PackageReconcilationContext) reconcilePackageInfoReady(ctx context.Cont
 		patches = p
 	}
 
+	if p, err := manifesttransformations.ResolveAndGeneratePatches(ctx, r.Client, r.pkg, piManifest); err != nil {
+		r.setShouldUpdate(
+			conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
+				condition.InstallationFailed, err.Error()))
+		return r.finalizeWithError(ctx, err)
+	} else {
+		patches = append(patches, p...)
+	}
+
 	// First, collect the adapters for all included manifests and ensure that they are supported.
 	// If one manifest type is not supported, no action must be performed!
 
@@ -232,6 +248,12 @@ func (r *PackageReconcilationContext) reconcilePackageInfoReady(ctx context.Cont
 	}
 }
 
+func (r *PackageReconcilationContext) reconcileSuspended(ctx context.Context) (ctrl.Result, error) {
+	log := ctrl.LoggerFrom(ctx)
+	log.Info("skipping reconciliation for suspended package")
+	return r.finalizeNoRequeue(ctx)
+}
+
 func (r *PackageReconcilationContext) reconcileAfterDeletion(ctx context.Context) (ctrl.Result, error) {
 	log := ctrl.LoggerFrom(ctx)
 
@@ -318,6 +340,7 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 			}
 
 			var newPkg ctrlpkg.Package
+			var pkgValues map[string]packagesv1alpha1.ValueConfiguration
 
 			if requirement.ComponentMetadata != nil {
 				newPkg = &packagesv1alpha1.Package{
@@ -326,6 +349,11 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 						Namespace: requirement.ComponentMetadata.Namespace,
 					},
 				}
+				for _, cmp := range r.pi.Status.Manifest.Components {
+					if cmp.Name == requirement.Name {
+						pkgValues = cmp.Values.AsPackageValues()
+					}
+				}
 			} else {
 				newPkg = &packagesv1alpha1.ClusterPackage{
 					ObjectMeta: metav1.ObjectMeta{
@@ -338,9 +366,7 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 
 			repositories, err := r.RepoClientset.Meta().GetReposForPackage(requirement.Name)
 			if err != nil {
-				log.Error(err, "could not find repos for package", "required", requirement.Name)
-				failed = append(failed, requirement.Name)
-				continue
+				log.Error(err, "could not get all repos for package", "required", requirement.Name)
 			}
 
 			var repositoryName string
@@ -363,6 +389,7 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 					Version:        requirement.Version,
 					RepositoryName: repositoryName,
 				}
+				newPkg.GetSpec().Values = pkgValues
 				return nil
 			}); err != nil {
 				log.Error(err, "Failed to create required package", "required", requirement.Name)
@@ -390,7 +417,10 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 	var ownedPackages []packagesv1alpha1.OwnedResourceRef
 	var waitingFor []string
 
-	var handleRequiredPackage = func(requiredPkg ctrlpkg.Package) error {
+	var handleRequiredPackage = func(
+		requiredPkg ctrlpkg.Package,
+		componentValues map[string]packagesv1alpha1.ValueConfiguration,
+	) error {
 		if err := r.Get(ctx, client.ObjectKeyFromObject(requiredPkg), requiredPkg); err != nil {
 			if apierrors.IsNotFound(err) {
 				waitingFor = append(waitingFor, requiredPkg.GetName())
@@ -405,6 +435,15 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 			} else {
 				ownedPackages = append(ownedPackages, owned)
 			}
+
+			if !reflect.DeepEqual(componentValues, requiredPkg.GetSpec().Values) {
+				requiredPkg.GetSpec().Values = componentValues
+				if err := r.Update(ctx, requiredPkg); err != nil {
+					log.Error(err, "Failed to update values of required package", "package", requiredPkg)
+					failed = append(failed, requiredPkg.GetName())
+				}
+			}
+
 			if meta.IsStatusConditionTrue(requiredPkg.GetStatus().Conditions, string(condition.Failed)) {
 				failed = append(failed, requiredPkg.GetName())
 			} else if !meta.IsStatusConditionTrue(requiredPkg.GetStatus().Conditions, string(condition.Ready)) {
@@ -419,7 +458,7 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 		requiredPkg := packagesv1alpha1.ClusterPackage{
 			ObjectMeta: metav1.ObjectMeta{Name: dep.Name},
 		}
-		if err := handleRequiredPackage(&requiredPkg); err != nil {
+		if err := handleRequiredPackage(&requiredPkg, nil); err != nil {
 			r.setShouldUpdate(conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
 				condition.InstallationFailed, err.Error()))
 			return false
@@ -436,13 +475,15 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 		if requiredPkg.Namespace == "" {
 			requiredPkg.Namespace = r.pi.Status.Manifest.DefaultNamespace
 		}
-		if err := handleRequiredPackage(&requiredPkg); err != nil {
+		if err := handleRequiredPackage(&requiredPkg, cmp.Values.AsPackageValues()); err != nil {
 			r.setShouldUpdate(conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
 				condition.InstallationFailed, err.Error()))
 			return false
 		}
 	}
 
+	r.setShouldUpdate(ownerutils.Add(&r.currentOwnedPackages, ownedPackages...))
+
 	if len(failed) > 0 {
 		message := fmt.Sprintf("required package(s) not installed: %v", strings.Join(failed, ","))
 		r.setShouldUpdate(conditions.SetFailed(ctx, r.EventRecorder, r.pkg, &r.pkg.GetStatus().Conditions,
@@ -457,8 +498,6 @@ func (r *PackageReconcilationContext) ensureDependencies(ctx context.Context) bo
 		return false
 	}
 
-	ownerutils.Add(&r.currentOwnedPackages, ownedPackages...)
-
 	return true
 }
 
