@@ -13,10 +13,12 @@ import (
 	ownerutils "github.com/glasskube/glasskube/internal/controller/owners/utils"
 	"github.com/glasskube/glasskube/internal/manifest"
 	"github.com/glasskube/glasskube/internal/manifest/result"
-	"github.com/glasskube/glasskube/internal/manifestvalues"
+	repoclient "github.com/glasskube/glasskube/internal/repo/client"
+	"github.com/glasskube/glasskube/internal/resourcepatch"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
@@ -29,6 +31,7 @@ var fieldOwner = client.FieldOwner("packages.glasskube.dev/package-controller")
 
 type Adapter struct {
 	client.Client
+	repo repoclient.RepoClientset
 	*owners.OwnerManager
 	namespaceGVK schema.GroupVersionKind
 }
@@ -38,11 +41,17 @@ func NewAdapter() manifest.ManifestAdapter {
 }
 
 // ControllerInit implements manifest.ManifestAdapter.
-func (a *Adapter) ControllerInit(builder *builder.Builder, client client.Client, scheme *runtime.Scheme) error {
+func (a *Adapter) ControllerInit(
+	builder *builder.Builder,
+	client client.Client,
+	repo repoclient.RepoClientset,
+	scheme *runtime.Scheme,
+) error {
 	if a.OwnerManager == nil {
 		a.OwnerManager = owners.NewOwnerManager(scheme)
 	}
 	a.Client = client
+	a.repo = repo
 	if nsGVK, err := client.GroupVersionKindFor(&corev1.Namespace{}); err != nil {
 		return err
 	} else {
@@ -56,7 +65,7 @@ func (a *Adapter) Reconcile(
 	ctx context.Context,
 	pkg ctrlpkg.Package,
 	pi *packagesv1alpha1.PackageInfo,
-	patches manifestvalues.TargetPatches,
+	patches resourcepatch.TargetPatches,
 ) (*result.ReconcileResult, error) {
 	var allOwned []packagesv1alpha1.OwnedResourceRef
 	for _, manifest := range pi.Status.Manifest.Manifests {
@@ -111,13 +120,13 @@ func (r *Adapter) reconcilePlainManifest(
 	pkg ctrlpkg.Package,
 	pi *packagesv1alpha1.PackageInfo,
 	manifest packagesv1alpha1.PlainManifest,
-	patches manifestvalues.TargetPatches,
+	patches resourcepatch.TargetPatches,
 ) ([]packagesv1alpha1.OwnedResourceRef, error) {
 	log := ctrl.LoggerFrom(ctx)
 	var objectsToApply []client.Object
-	if url, err := getActualManifestUrl(pi, manifest.Url); err != nil {
+	if request, err := r.newManifestRequest(pi, manifest.Url); err != nil {
 		return nil, err
-	} else if unstructured, err := clientutils.FetchResources(url); err != nil {
+	} else if unstructured, err := clientutils.FetchResources(request); err != nil {
 		return nil, err
 	} else {
 		// Unstructured implements client.Object but we need it as a reference so the interface is fulfilled.
@@ -125,7 +134,9 @@ func (r *Adapter) reconcilePlainManifest(
 		for i := range unstructured {
 			objectsToApply[i] = &unstructured[i]
 		}
-		log.V(1).Info("fetched "+url, "objectCount", len(objectsToApply))
+		log.V(1).Info("fetched manifest resources",
+			"url", request.URL.Redacted(),
+			"objectCount", len(objectsToApply))
 	}
 
 	if pkg.IsNamespaceScoped() {
@@ -183,10 +194,19 @@ func (r *Adapter) reconcilePlainManifest(
 		}
 	}
 
-	// TODO: check if namespace is terminating before applying
+	specHash, specHashErr := pkg.GetSpec().Hashed()
+	if specHashErr != nil {
+		log.Error(specHashErr, "failed to get spec hash for package – restarts might not happen", "package", pkg)
+	}
 
+	// TODO: check if namespace is terminating before applying
 	// Apply any modifications before changing anything on the cluster
 	for _, obj := range objectsToApply {
+		if specHashErr == nil {
+			if err := r.annotateWithSpecHash(obj, specHash); err != nil {
+				log.Error(err, "could not annotate object with spec hash", "package", pkg, "object", obj)
+			}
+		}
 		if err := r.SetOwnerIfManagedOrNotExists(r.Client, ctx, pkg, obj); err != nil {
 			return nil, err
 		}
@@ -214,3 +234,23 @@ func (r *Adapter) reconcilePlainManifest(
 	}
 	return ownedResources, nil
 }
+
+// if the obj kind is Deployment or StatefulSet annotateWithSpecHash sets the AnnotationPackageSpecHashed annotation of the
+// template to the given specHash. For any other kind it does nothing. Updating the template's annotation to a
+// different value than the existing one, will trigger a rolling restart of the resource. When the value stays the same,
+// the resource will not be restarted.
+func (r *Adapter) annotateWithSpecHash(obj client.Object, specHash string) error {
+	switch obj.GetObjectKind().GroupVersionKind().Kind {
+	case constants.Deployment, constants.StatefulSet:
+		if unstructuredObj, ok := obj.(runtime.Unstructured); ok {
+			objContent := unstructuredObj.UnstructuredContent()
+			err := unstructured.SetNestedField(objContent, specHash,
+				"spec", "template", "metadata", "annotations", packagesv1alpha1.AnnotationPackageSpecHashed)
+			if err != nil {
+				return err
+			}
+			unstructuredObj.SetUnstructuredContent(objContent)
+		}
+	}
+	return nil
+}
