@@ -3,6 +3,7 @@ package client
 import (
 	packagesv1alpha1 "github.com/glasskube/glasskube/api/v1alpha1"
 	"github.com/glasskube/glasskube/internal/controller/ctrlpkg"
+	"github.com/glasskube/glasskube/internal/repo/client/auth"
 	"github.com/glasskube/glasskube/internal/repo/types"
 )
 
@@ -11,6 +12,7 @@ type LatestVersionGetter interface {
 }
 
 type RepoClient interface {
+	auth.Authenticator
 	LatestVersionGetter
 	FetchPackageRepoIndex(target *types.PackageRepoIndex) error
 	FetchLatestPackageManifest(name string, target *packagesv1alpha1.PackageManifest) (version string, err error)
